package com.ruoyi.framework.recovery.service;

import java.util.List;
import com.ruoyi.framework.recovery.domain.RecStall;
import com.ruoyi.framework.recovery.domain.vo.RecStallGoodsVo;

/**
 * 回收档口Service接口
 * 
 * @author jin
 * @date 2024-11-16
 */
public interface IRecStallService 
{
    /**
     * 查询回收档口
     * 
     * @param id 回收档口主键
     * @return 回收档口
     */
    public RecStall selectRecStallById(Long id);

    /**
     * 查询回收档口列表
     * 
     * @param recStall 回收档口
     * @return 回收档口集合
     */
    public List<RecStall> selectRecStallList(RecStall recStall);

    /**
     * 新增回收档口
     * 
     * @param recStall 回收档口
     * @return 结果
     */
    public int insertRecStall(RecStall recStall);

    /**
     * 修改回收档口
     * 
     * @param recStall 回收档口
     * @return 结果
     */
    public int updateRecStall(RecStall recStall);

    /**
     * 批量删除回收档口
     * 
     * @param ids 需要删除的回收档口主键集合
     * @return 结果
     */
    public int deleteRecStallByIds(Long[] ids);

    /**
     * 删除回收档口信息
     * 
     * @param id 回收档口主键
     * @return 结果
     */
    public int deleteRecStallById(Long id);

    /**
     * 查询所有商品
     *
     * @return 商品结果集
     */
    List<RecStallGoodsVo> selectGoodsList();
}
